@@ -16,7 +16,7 @@ DATA_POINT_DAILYRAININ = "dailyrainin"
 DATA_POINT_DEWPOINT = "dewpoint"
 DATA_POINT_EVENTRAIN = "eventrain"
 DATA_POINT_EVENTRAININ = "eventrainin"
-DATA_POINT_FEELSLIKEF = "feelslikef"
+DATA_POINT_FEELSLIKE = "feelslike"
 DATA_POINT_HEATINDEX = "heatindex"
 DATA_POINT_HOURLYRAIN = "hourlyrain"
 DATA_POINT_HOURLYRAININ = "hourlyrainin"
