@@ -16,7 +16,7 @@ from ecowitt2mqtt.const import (
     DATA_POINT_DEWPOINT,
     DATA_POINT_EVENTRAIN,
     DATA_POINT_EVENTRAININ,
-    DATA_POINT_FEELSLIKEF,
+    DATA_POINT_FEELSLIKE,
     DATA_POINT_HEATINDEX,
     DATA_POINT_HOURLYRAIN,
     DATA_POINT_HOURLYRAININ,
@@ -233,9 +233,9 @@ class DataProcessor:  # pylint: disable=too-many-instance-attributes
                 continue
 
             if self._unit_system == UNIT_SYSTEM_METRIC:
-                data[new_key] = round(in_to_mm(int(self._data[original_key])), 1)
+                data[new_key] = round(in_to_mm(int(float(self._data[original_key]))), 1)
             else:
-                data[new_key] = int(self._data[original_key])
+                data[new_key] = int(float(self._data[original_key]))
 
         return data
 
@@ -246,7 +246,6 @@ class DataProcessor:  # pylint: disable=too-many-instance-attributes
         # Outdoor temperature (which we've already calculated):
         if self._temperature_obj:
             if self._unit_system == UNIT_SYSTEM_METRIC:
-                self._data.pop(DATA_POINT_TEMPF)
                 data[DATA_POINT_TEMP] = round(self._temperature_obj.c, 1)
             else:
                 data[DATA_POINT_TEMP] = round(self._temperature_obj.f, 1)
@@ -288,7 +287,7 @@ class DataProcessor:  # pylint: disable=too-many-instance-attributes
         # Calculated temperatures:
         for key, obj_property in [
             (DATA_POINT_DEWPOINT, self._dew_point_obj),
-            (DATA_POINT_FEELSLIKEF, self._feels_like_obj),
+            (DATA_POINT_FEELSLIKE, self._feels_like_obj),
             (DATA_POINT_HEATINDEX, self._heat_index_obj),
             (DATA_POINT_WINDCHILL, self._wind_chill_obj),
         ]:
@@ -360,6 +359,7 @@ class DataProcessor:  # pylint: disable=too-many-instance-attributes
             DATA_POINT_TEMP7F,
             DATA_POINT_TEMP8F,
             DATA_POINT_TEMP9F,
+            DATA_POINT_TEMPF,
             DATA_POINT_TEMPINF,
             DATA_POINT_TOTALRAININ,
             DATA_POINT_WEEKLYRAININ,
